@@ -877,12 +877,12 @@ class World:
     def __init__(self, name="PyBlockWorld"):
         self.window = Window(width=800, height=600, 
             caption=name, resizable=True)
-        self.window.unknown_key_pressed = self.__build_key_function
+        self.window.unknown_key_pressed = self.unknown_key_pressed
 
     def build_key_pressed(self, world):
         print("b pressed.")
 
-    def __build_key_function(self, symbol):
+    def unknown_key_pressed(self, symbol):
         #print(symbol, "pressed")
         if symbol == key.B:
             self.build_key_pressed(self)
